==> amen_0.91.tar.gz: amen/man/rZ_cbin_fc.Rd <==
\name{rZ_cbin_fc}
\alias{rZ_cbin_fc}
\title{
Simulate Z given fixed rank nomination data
}
\description{
Simulates a random latent matrix Z given its expectation, dyadic correlation and 
censored binary nomination data
}
\usage{
rZ_cbin_fc(Z, EZ, rho, Y, odmax, odobs)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Z}{
a square matrix, the current value of Z
}
  \item{EZ}{
expected value of Z
}
  \item{rho}{
dyadic correlation
}
  \item{Y}{
square matrix of ranked nomination data
}
  \item{odmax}{
a scalar or vector giving the maximum number of nominations for each individual
}
  \item{odobs}{
observed outdegree
}
}
\details{
  simulates Z under the contraints
   (1)  Y[i,j]=1, Y[i,k]=0           => Z[i,j]>Z[i,k]  ,  
   (2)  Y[i,j]=1                     => Z[i,j]>0     , 
   (3)  Y[i,j]=0 & odobs[i]<odmax[i] => Z[i,j]<0
}
\value{
a square matrix, the new value of Z
}
\author{Peter Hoff}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\examples{
## The function is currently defined as
function(Z,EZ,rho,Y,odmax,odobs)
{
  # simulates Z under the contraints 
  # (1)  Y[i,j] > Y[i,k]              => Z[i,j]>Z[i,k]  
  # (2)  Y[i,j]>0                     => Z[i,j]>0    
  # (3)  Y[i,j]=0 & odobs[i]<odmax[i] => Z[i,j]<0

  sz<-sqrt(1-rho^2)
  ut<-upper.tri(EZ)
  lt<-lower.tri(EZ)

  for(y in sample(0:1))
  {
    if(y==1)
    { 
      ub<- Inf
      lbm<-matrix(pmax(apply(Z-(Y!=0)*(Inf^(Y!=0)),1,max,na.rm=TRUE),0),
                  nrow(Z),nrow(Z))
    }

    if(y==0)
    { 
      lb<- -Inf
      ubm<-matrix(apply(Z+(Y!=1)*(Inf^(Y!=1)),1,min,na.rm=TRUE),nrow(Z), 
                  nrow(Z))
      ubm[ odobs<odmax ] <- 0 
    }

    up<- ut & Y==y 
    if(y==0)  { ub<-ubm[up] }  
    if(y==1)  { lb<-lbm[up] }
    ez<- EZ[up] + rho*( t(Z)[up]  - t(EZ)[up] )
    Z[up]<-ez+sz*qnorm(runif(sum(up),pnorm((lb-ez)/sz),pnorm((ub-ez)/sz)))

    up<- lt & Y==y
    if(y==0)  { ub<-ubm[up] }
    if(y==1)  { lb<-lbm[up] }
    ez<- EZ[up] + rho*( t(Z)[up]  - t(EZ)[up] )
    Z[up]<-ez+sz*qnorm(runif(sum(up),pnorm((lb-ez)/sz),pnorm((ub-ez)/sz)))
  }

  #diag(Z)<-rnorm(nrow(Z),diag(EZ),1)
  Z[is.na(Y)]<- rnorm(sum(is.na(Y)),EZ[is.na(Y)],1)
  Z
}


}

==> amen_0.999.tar.gz: amen/man/rZ_cbin_fc.Rd <==
\name{rZ_cbin_fc}
\alias{rZ_cbin_fc}
\title{
Simulate Z given fixed rank nomination data
}
\description{
Simulates a random latent matrix Z given its expectation, dyadic correlation and 
censored binary nomination data
}
\usage{
rZ_cbin_fc(Z, EZ, rho, Y, odmax, odobs)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Z}{
a square matrix, the current value of Z
}
  \item{EZ}{
expected value of Z
}
  \item{rho}{
dyadic correlation
}
  \item{Y}{
square matrix of ranked nomination data
}
  \item{odmax}{
a scalar or vector giving the maximum number of nominations for each individual
}
  \item{odobs}{
observed outdegree
}
}
\details{
  simulates Z under the constraints
   (1)  Y[i,j]=1, Y[i,k]=0           => Z[i,j]>Z[i,k]  ,  
   (2)  Y[i,j]=1                     => Z[i,j]>0     , 
   (3)  Y[i,j]=0 & odobs[i]<odmax[i] => Z[i,j]<0
}
\value{
a square matrix, the new value of Z
}
\author{Peter Hoff}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\examples{
## The function is currently defined as
function(Z,EZ,rho,Y,odmax,odobs)
{
  # simulates Z under the constraints 
  # (1)  Y[i,j] > Y[i,k]              => Z[i,j]>Z[i,k]  
  # (2)  Y[i,j]>0                     => Z[i,j]>0    
  # (3)  Y[i,j]=0 & odobs[i]<odmax[i] => Z[i,j]<0

  sz<-sqrt(1-rho^2)
  ut<-upper.tri(EZ)
  lt<-lower.tri(EZ)

  for(y in sample(0:1))
  {
    if(y==1)
    { 
      ub<- Inf
      lbm<-matrix(pmax(apply(Z-(Y!=0)*(Inf^(Y!=0)),1,max,na.rm=TRUE),0),
                  nrow(Z),nrow(Z))
    }

    if(y==0)
    { 
      lb<- -Inf
      ubm<-matrix(apply(Z+(Y!=1)*(Inf^(Y!=1)),1,min,na.rm=TRUE),nrow(Z), 
                  nrow(Z))
      ubm[ odobs<odmax ] <- 0 
    }

    up<- ut & Y==y 
    if(y==0)  { ub<-ubm[up] }  
    if(y==1)  { lb<-lbm[up] }
    ez<- EZ[up] + rho*( t(Z)[up]  - t(EZ)[up] )
    Z[up]<-ez+sz*qnorm(runif(sum(up),pnorm((lb-ez)/sz),pnorm((ub-ez)/sz)))

    up<- lt & Y==y
    if(y==0)  { ub<-ubm[up] }
    if(y==1)  { lb<-lbm[up] }
    ez<- EZ[up] + rho*( t(Z)[up]  - t(EZ)[up] )
    Z[up]<-ez+sz*qnorm(runif(sum(up),pnorm((lb-ez)/sz),pnorm((ub-ez)/sz)))
  }

  #diag(Z)<-rnorm(nrow(Z),diag(EZ),1)
  Z[is.na(Y)]<- rnorm(sum(is.na(Y)),EZ[is.na(Y)],1)
  Z
}


}
